import { Container, interfaces } from 'inversify';
import * as path from 'path';
import { terminalMicroserviceModule } from '@xterm-stack/microservice-nats';
import { TaggedType } from '@common-stack/core';
import {
    ITerminalService,
    TYPES as terminalServiceTypes, ITerminalMicroservice,
    TerminalLocalservice,
    terminalModule,
    preferences as xtermPreferences,
} from '@xterm-stack/server-core';
import { Feature } from '@common-stack/server-core';
import { typeDefs, resolver } from '@xterm-stack/graphql-schema';

const terminalServiceGen = (container: interfaces.Container) => {
    const environment = container.get('Environment');
    if (environment === 'development') {
        return { terminalService: container.get<ITerminalMicroservice>(terminalServiceTypes.ITerminalMicroservice) };
    } else {
        return { terminalService: container.getNamed<ITerminalMicroservice>(terminalServiceTypes.ITerminalMicroservice, TaggedType.MICROSERVICE) };
    }
};
export default new Feature({
    createPreference: xtermPreferences,
    createContainerFunc: [terminalModule, terminalMicroserviceModule],
    createResolversFunc: resolver,
    schema: typeDefs,
    createServiceFunc: terminalServiceGen,
} as any);
